summaryrefslogtreecommitdiffstats
path: root/skia
diff options
context:
space:
mode:
Diffstat (limited to 'skia')
-rw-r--r--skia/ext/SkFontHost_fontconfig_direct.cpp13
1 files changed, 9 insertions, 4 deletions
diff --git a/skia/ext/SkFontHost_fontconfig_direct.cpp b/skia/ext/SkFontHost_fontconfig_direct.cpp
index 2e19928..279af90 100644
--- a/skia/ext/SkFontHost_fontconfig_direct.cpp
+++ b/skia/ext/SkFontHost_fontconfig_direct.cpp
@@ -26,8 +26,8 @@
namespace {
// Equivalence classes, used to match the Liberation fonts with their
// metric-compatible replacements. See the discussion in
// GetFontEquivClass().
enum FontEquivClass
{
@@ -50,11 +50,16 @@ FontEquivClass GetFontEquivClass(const char* fontname)
// /etc/fonts/conf.d/30-metric-aliases.conf
// from my Ubuntu system, but we're better off being very conservative.
+ // "Ascender Sans" and "Ascender Serif" are the tentative names of
+ // another set of fonts metric-compatible with Arial and Times New Roman
+ // with a character repertoire much larger than Liberation.
if (strcasecmp(fontname, "Arial") == 0 ||
- strcasecmp(fontname, "Liberation Sans") == 0) {
+ strcasecmp(fontname, "Liberation Sans") == 0 ||
+ strcasecmp(fontname, "Ascender Sans") == 0) {
return SANS;
} else if (strcasecmp(fontname, "Times New Roman") == 0 ||
- strcasecmp(fontname, "Liberation Serif") == 0) {
+ strcasecmp(fontname, "Liberation Serif") == 0 ||
+ strcasecmp(fontname, "Ascender Serif") == 0) {
return SERIF;
}
return OTHER;
@@ -26,8 +26,8 @@
namespace {
-// Equivalence classes, used to match the Liberation fonts with their
-// metric-compatible replacements. See the discussion in
+// Equivalence classes, used to match the Liberation and Ascender fonts
+// with their metric-compatible replacements. See the discussion in
// GetFontEquivClass().
enum FontEquivClass